@@ -14,6 +14,16 @@ from .optimizer.nsga_optimizer import NSGAOptimizer
 
 from .utils.start_smbo import create_smbo as create_optimizer
 
+from .core.generic_advisor import Advisor
+from .core.async_batch_advisor import AsyncBatchAdvisor
+from .core.sync_batch_advisor import SyncBatchAdvisor
+from .core.random_advisor import RandomAdvisor
+from .core.tpe_advisor import TPE_Advisor
+from .core.ea_advisor import EA_Advisor
+from .core.mc_advisor import MCAdvisor
+
+from .core.base import Observation
+
 from .utils.tuning import get_config_space, get_objective_function
 
 from .utils.test_install import run_test
@@ -24,6 +34,10 @@ __all__ = [
     "Optimizer", "ParallelOptimizer", "DistributedOptimizer", "DistributedWorker",
     "NSGAOptimizer",
     "create_optimizer",
+    "Advisor",
+    "AsyncBatchAdvisor", "SyncBatchAdvisor",
+    "RandomAdvisor", "TPE_Advisor", "EA_Advisor", "MCAdvisor",
+    "Observation",
     "get_config_space", "get_objective_function",
     "run_test",
 ]
