@@ -12,6 +12,7 @@ from openbox.utils.config_space import Configuration
 from openbox.core.base import Observation
 
 from openbox.artifact.data_manipulation.db_object import User, Task, Runhistory
+from user_board.utils.common import get_password
 
 # Global mapping from task_id to config advisor
 advisor_dict = {}
@@ -42,7 +43,7 @@ def task_register(request):
             if user is None:
                 return JsonResponse({'code': 0, 'msg': '[bo_advice/views.py] User does not exist'})
             else:
-                if user['password'] != hashlib.md5(password.encode(encoding='utf-8')).hexdigest():
+                if user['password'] != get_password(password):
                     return JsonResponse({'code': 0, 'msg': '[bo_advice/views.py] Incorrect Password'})
 
             # task_id = request.POST.get('task_id')
@@ -51,7 +52,6 @@ def task_register(request):
 
             num_constraints = int(request.POST.get('num_constraints', 0))
             num_objs = int(request.POST.get('num_objs', 1))
-            task_info = {'num_constraints': num_constraints, 'num_objs': num_objs}
             options = json.loads(request.POST.get('options', '{}'))
 
             time_limit_per_trial = int(request.POST.get('time_limit_per_trial', 300))
@@ -80,7 +80,8 @@ def task_register(request):
 
             if advisor_type == 'default':
                 from openbox.core.generic_advisor import Advisor
-                config_advisor = Advisor(config_space, task_info, task_id=task_id, **options)
+                config_advisor = Advisor(config_space, num_objs=num_objs, num_constraints=num_constraints,
+                                         task_id=task_id, **options)
             elif advisor_type == 'tpe':
                 from openbox.core.tpe_advisor import TPE_Advisor
                 config_advisor = TPE_Advisor(config_space)
@@ -163,7 +164,10 @@ def update_observation(request):
                 'worker_id': trial_info['worker_id'],
                 'cost': trial_info['cost']}
             runhistory_id = Runhistory().insert_one(item)
-            observation = Observation(config, trial_state, constraints, objs, trial_info['cost'])
+            observation = Observation(
+                config=config, objs=objs, constraints=constraints,
+                trial_state=trial_state, elapsed_time=trial_info['cost'],
+            )
             config_advisor.update_observation(observation)
 
             config_advisor.save_history()
