@@ -8,7 +8,6 @@ import copy
 import numpy as np
 from openbox.optimizer.nsga_base import NSGABase
 from openbox.utils.constants import MAXINT
-from openbox.core.base import Observation
 from openbox.utils.platypus_utils import get_variator, set_problem_types, objective_wrapper
 from openbox.utils.config_space import Configuration
 from platypus import Problem, NSGAII
@@ -28,7 +27,7 @@ class NSGAOptimizer(NSGABase):
                  algorithm='nsgaii',
                  logging_dir='logs',
                  task_id='default_task_id',
-                 random_state=1,
+                 random_state=None,
                  **kwargs):
 
         if task_id is None:
